@@ -1,13 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-
 #include "plaintextmarkupbuildertest.h"
-#include <KPIMTextEdit/PlainTextMarkupBuilder>
 #include <KPIMTextEdit/MarkupDirector>
+#include <KPIMTextEdit/PlainTextMarkupBuilder>
 #include <QRegularExpression>
 #include <QTest>
 #include <QTextDocument>
@@ -16,24 +15,29 @@ QTEST_MAIN(PlainTextMarkupBuilderTest)
 PlainTextMarkupBuilderTest::PlainTextMarkupBuilderTest(QObject *parent)
     : QObject(parent)
 {
-
 }
 
-
 void PlainTextMarkupBuilderTest::testPlainText_data()
 {
     QTest::addColumn<QString>("text");
     QTest::addColumn<QString>("regexpText");
-    QTest::newRow("text with espace at begin") <<  QString() << QString();
+    QTest::newRow("text with espace at begin") << QString() << QString();
     QTest::newRow("bold") << QStringLiteral("This <b>text</b> is bold.") << QStringLiteral("^This \\*text\\* is bold.\\n$");
     QTest::newRow("double format") << QStringLiteral("Some <b><i>formatted</i></b> text.") << QStringLiteral("^Some (\\*/|/\\*)formatted(\\*/|/\\*) text.\\n$");
     QTest::newRow("italic") << QStringLiteral("This <b>text is <i>italic</i> and</b> bold.") << QStringLiteral("^This \\*text is /italic/ and\\* bold.\\n$");
-    QTest::newRow("double span") << QStringLiteral("Some <span "
-                                                   "style=\"color:#ff0000;background-color:#00ff00;"
-                                                   "\">formatted</span> text.") << QStringLiteral("^Some formatted text.\\n$");
+    QTest::newRow("double span") << QStringLiteral(
+        "Some <span "
+        "style=\"color:#ff0000;background-color:#00ff00;"
+        "\">formatted</span> text.")
+                                 << QStringLiteral("^Some formatted text.\\n$");
 
-    //FIXME bug is about id="..."
-    QTest::newRow("bug345360") << QStringLiteral("<html><body><center><table><tr><td><div id=\"foo\"><span>    Dear User,       </span> <br> <br> <span>    We     have updated our Privacy Policy and Terms of Service. Please take a    few  minutes to read and understand them. To help you understand, we    have  summarized the changes and provided a comparison of the current    and the  previous versions.       </span> <br> <br> <span>    These     changes will take effect on April 19, 2015.&nbsp; If you continue to use     Zoho after April 19, 2015, you will be governed by the new Privacy     Policy and Terms of Service.       </span> <br> <br> <span>  ddd &nbsp;&nbsp;&nbsp;&nbsp;       </span></td></tr></table></center></body></html>")
+    // FIXME bug is about id="..."
+    QTest::newRow("bug345360") << QStringLiteral(
+        "<html><body><center><table><tr><td><div id=\"foo\"><span>    Dear User,       </span> <br> <br> <span>    We     have updated our Privacy Policy and "
+        "Terms of Service. Please take a    few  minutes to read and understand them. To help you understand, we    have  summarized the changes and provided "
+        "a comparison of the current    and the  previous versions.       </span> <br> <br> <span>    These     changes will take effect on April 19, "
+        "2015.&nbsp; If you continue to use     Zoho after April 19, 2015, you will be governed by the new Privacy     Policy and Terms of Service.       "
+        "</span> <br> <br> <span>  ddd &nbsp;&nbsp;&nbsp;&nbsp;       </span></td></tr></table></center></body></html>")
                                << QStringLiteral("foo");
 }
 
@@ -79,7 +83,6 @@ void PlainTextMarkupBuilderTest::testSingleFormat()
     delete md;
     delete hb;
     delete doc;
-
 }
 
 void PlainTextMarkupBuilderTest::testDoubleFormat()
@@ -93,29 +96,25 @@ void PlainTextMarkupBuilderTest::testDoubleFormat()
     auto md = new KPIMTextEdit::MarkupDirector(hb);
     md->processDocument(doc);
     auto result = hb->getResult();
-    QRegularExpression regex(
-                QStringLiteral("^Some (\\*/|/\\*)formatted(\\*/|/\\*) text.\\n$"));
+    QRegularExpression regex(QStringLiteral("^Some (\\*/|/\\*)formatted(\\*/|/\\*) text.\\n$"));
 
     QVERIFY(regex.match(result).hasMatch());
     delete md;
     delete hb;
     delete doc;
-
 }
 
 void PlainTextMarkupBuilderTest::testAnchor()
 {
     auto doc = new QTextDocument();
-    doc->setHtml(
-                QStringLiteral("A <a href=\"http://www.kde.org\">link</a> to KDE."));
+    doc->setHtml(QStringLiteral("A <a href=\"http://www.kde.org\">link</a> to KDE."));
 
     auto hb = new KPIMTextEdit::PlainTextMarkupBuilder();
     auto md = new KPIMTextEdit::MarkupDirector(hb);
     md->processDocument(doc);
     auto result = hb->getResult();
 
-    QRegularExpression regex(QStringLiteral(
-                                 "^A link\\[1\\] to KDE.\\n\\n--------\\n\\[1\\] http://www.kde.org\\n$"));
+    QRegularExpression regex(QStringLiteral("^A link\\[1\\] to KDE.\\n\\n--------\\n\\[1\\] http://www.kde.org\\n$"));
 
     regex.match(result).hasMatch();
 
@@ -123,14 +122,12 @@ void PlainTextMarkupBuilderTest::testAnchor()
     delete md;
     delete hb;
     delete doc;
-
 }
 
 void PlainTextMarkupBuilderTest::testAnchorWithFormattedContent()
 {
     auto doc = new QTextDocument();
-    doc->setHtml(QStringLiteral(
-                     "A <a href=\"http://www.kde.org\"><b>formatted</b> link</a> to KDE."));
+    doc->setHtml(QStringLiteral("A <a href=\"http://www.kde.org\"><b>formatted</b> link</a> to KDE."));
 
     auto hb = new KPIMTextEdit::PlainTextMarkupBuilder();
     auto md = new KPIMTextEdit::MarkupDirector(hb);
@@ -138,37 +135,35 @@ void PlainTextMarkupBuilderTest::testAnchorWithFormattedContent()
     auto result = hb->getResult();
 
     QRegularExpression regex(
-                QStringLiteral("^A \\*formatted\\* link\\[1\\] to "
-                               "KDE.\\n\\n--------\\n\\[1\\] http://www.kde.org\\n$"));
+        QStringLiteral("^A \\*formatted\\* link\\[1\\] to "
+                       "KDE.\\n\\n--------\\n\\[1\\] http://www.kde.org\\n$"));
 
     QVERIFY(regex.match(result).hasMatch());
     delete md;
     delete hb;
     delete doc;
-
 }
 
 void PlainTextMarkupBuilderTest::testAdjacentAnchors()
 {
     auto doc = new QTextDocument();
     doc->setHtml(
-                QStringLiteral("Two <a href=\"http://www.kde.org\">links</a><a "
-                               "href=\"http://www.google.com\">next</a> to eachother."));
+        QStringLiteral("Two <a href=\"http://www.kde.org\">links</a><a "
+                       "href=\"http://www.google.com\">next</a> to eachother."));
 
     auto hb = new KPIMTextEdit::PlainTextMarkupBuilder();
     auto md = new KPIMTextEdit::MarkupDirector(hb);
     md->processDocument(doc);
     auto result = hb->getResult();
 
-    QRegularExpression regex(QStringLiteral(
-                                 "^Two links\\[1\\]next\\[2\\] to eachother.\\n\\n--------\\n\\[1\\] "
-                                 "http://www.kde.org\\n\\[2\\] http://www.google.com\\n$"));
+    QRegularExpression regex(
+        QStringLiteral("^Two links\\[1\\]next\\[2\\] to eachother.\\n\\n--------\\n\\[1\\] "
+                       "http://www.kde.org\\n\\[2\\] http://www.google.com\\n$"));
 
     QVERIFY(regex.match(result).hasMatch());
     delete md;
     delete hb;
     delete doc;
-
 }
 
 void PlainTextMarkupBuilderTest::testNestedFormatting()
@@ -181,21 +176,18 @@ void PlainTextMarkupBuilderTest::testNestedFormatting()
     md->processDocument(doc);
     auto result = hb->getResult();
 
-    QRegularExpression regex(
-                QStringLiteral("^This \\*text is /italic/ and\\* bold.\\n$"));
+    QRegularExpression regex(QStringLiteral("^This \\*text is /italic/ and\\* bold.\\n$"));
 
     QVERIFY(regex.match(result).hasMatch());
     delete md;
     delete hb;
     delete doc;
-
 }
 
 void PlainTextMarkupBuilderTest::testSpan()
 {
     auto doc = new QTextDocument();
-    doc->setHtml(QStringLiteral(
-                     "Some <span style=\"color:#ff0000;\">formatted</span> text."));
+    doc->setHtml(QStringLiteral("Some <span style=\"color:#ff0000;\">formatted</span> text."));
 
     auto hb = new KPIMTextEdit::PlainTextMarkupBuilder();
     auto md = new KPIMTextEdit::MarkupDirector(hb);
@@ -208,15 +200,15 @@ void PlainTextMarkupBuilderTest::testSpan()
     delete md;
     delete hb;
     delete doc;
-
 }
 
 void PlainTextMarkupBuilderTest::testDoubleSpan()
 {
     auto doc = new QTextDocument();
-    doc->setHtml(QStringLiteral("Some <span "
-                                "style=\"color:#ff0000;background-color:#00ff00;"
-                                "\">formatted</span> text."));
+    doc->setHtml(
+        QStringLiteral("Some <span "
+                       "style=\"color:#ff0000;background-color:#00ff00;"
+                       "\">formatted</span> text."));
 
     auto hb = new KPIMTextEdit::PlainTextMarkupBuilder();
     auto md = new KPIMTextEdit::MarkupDirector(hb);
@@ -229,134 +221,116 @@ void PlainTextMarkupBuilderTest::testDoubleSpan()
     delete md;
     delete hb;
     delete doc;
-
 }
 
 void PlainTextMarkupBuilderTest::testSpanNesting()
 {
     auto doc = new QTextDocument();
-    doc->setHtml(QStringLiteral(
-                     "Paragraph <span style=\"background-color:#00ff00;\">with some <span "
-                     "style=\"color:#ff0000;\">formatted</span> nested</span> text."));
+    doc->setHtml(
+        QStringLiteral("Paragraph <span style=\"background-color:#00ff00;\">with some <span "
+                       "style=\"color:#ff0000;\">formatted</span> nested</span> text."));
 
     auto hb = new KPIMTextEdit::PlainTextMarkupBuilder();
     auto md = new KPIMTextEdit::MarkupDirector(hb);
     md->processDocument(doc);
     auto result = hb->getResult();
 
-    auto regex = QRegularExpression(
-                QStringLiteral("^Paragraph with some formatted nested text.\\n$"));
+    auto regex = QRegularExpression(QStringLiteral("^Paragraph with some formatted nested text.\\n$"));
 
     QVERIFY(regex.match(result).hasMatch());
     delete md;
     delete hb;
     delete doc;
-
 }
 
 void PlainTextMarkupBuilderTest::testDoubleStartDifferentFinish()
 {
     auto doc = new QTextDocument();
-    doc->setHtml(
-                QStringLiteral("Paragraph <i><b>with</b> some formatted</i> text."));
+    doc->setHtml(QStringLiteral("Paragraph <i><b>with</b> some formatted</i> text."));
 
     auto hb = new KPIMTextEdit::PlainTextMarkupBuilder();
     auto md = new KPIMTextEdit::MarkupDirector(hb);
     md->processDocument(doc);
     auto result = hb->getResult();
 
-    auto regex = QRegularExpression(
-                QStringLiteral("^Paragraph /\\*with\\* some formatted/ text.\\n$"));
+    auto regex = QRegularExpression(QStringLiteral("^Paragraph /\\*with\\* some formatted/ text.\\n$"));
 
     QVERIFY(regex.match(result).hasMatch());
     delete md;
     delete hb;
     delete doc;
-
 }
 
 void PlainTextMarkupBuilderTest::testDoubleStartDifferentFinishReverseOrder()
 {
     auto doc = new QTextDocument();
-    doc->setHtml(
-                QStringLiteral("Paragraph <b><i>with</i> some formatted</b> text."));
+    doc->setHtml(QStringLiteral("Paragraph <b><i>with</i> some formatted</b> text."));
 
     auto hb = new KPIMTextEdit::PlainTextMarkupBuilder();
     auto md = new KPIMTextEdit::MarkupDirector(hb);
     md->processDocument(doc);
     auto result = hb->getResult();
 
-    auto regex = QRegularExpression(
-                QStringLiteral("^Paragraph \\*/with/ some formatted\\* text.\\n$"));
+    auto regex = QRegularExpression(QStringLiteral("^Paragraph \\*/with/ some formatted\\* text.\\n$"));
 
     QVERIFY(regex.match(result).hasMatch());
     delete md;
     delete hb;
     delete doc;
-
 }
 
 void PlainTextMarkupBuilderTest::testDifferentStartDoubleFinish()
 {
     auto doc = new QTextDocument();
-    doc->setHtml(
-                QStringLiteral("Paragraph <i>with some <b>formatted<b></i> text."));
+    doc->setHtml(QStringLiteral("Paragraph <i>with some <b>formatted<b></i> text."));
 
     auto hb = new KPIMTextEdit::PlainTextMarkupBuilder();
     auto md = new KPIMTextEdit::MarkupDirector(hb);
     md->processDocument(doc);
     auto result = hb->getResult();
 
-    auto regex = QRegularExpression(
-                QStringLiteral("^Paragraph /with some \\*formatted\\*/ text.\\n$"));
+    auto regex = QRegularExpression(QStringLiteral("^Paragraph /with some \\*formatted\\*/ text.\\n$"));
 
     QVERIFY(regex.match(result).hasMatch());
     delete md;
     delete hb;
     delete doc;
-
 }
 
 void PlainTextMarkupBuilderTest::testDifferentStartDoubleFinishReverseOrder()
 {
     auto doc = new QTextDocument();
-    doc->setHtml(
-                QStringLiteral("Paragraph <b>with some <i>formatted</i></b> text."));
+    doc->setHtml(QStringLiteral("Paragraph <b>with some <i>formatted</i></b> text."));
 
     auto hb = new KPIMTextEdit::PlainTextMarkupBuilder();
     auto md = new KPIMTextEdit::MarkupDirector(hb);
     md->processDocument(doc);
     auto result = hb->getResult();
 
-    auto regex = QRegularExpression(
-                QStringLiteral("^Paragraph \\*with some /formatted/\\* text.\\n$"));
+    auto regex = QRegularExpression(QStringLiteral("^Paragraph \\*with some /formatted/\\* text.\\n$"));
 
     QVERIFY(regex.match(result).hasMatch());
     delete md;
     delete hb;
     delete doc;
-
 }
 
 void PlainTextMarkupBuilderTest::testOverlap()
 {
     auto doc = new QTextDocument();
-    doc->setHtml(QStringLiteral(
-                     "Paragraph <b>with <i>some</i></b><i> formatted</i> text."));
+    doc->setHtml(QStringLiteral("Paragraph <b>with <i>some</i></b><i> formatted</i> text."));
 
     auto hb = new KPIMTextEdit::PlainTextMarkupBuilder();
     auto md = new KPIMTextEdit::MarkupDirector(hb);
     md->processDocument(doc);
     auto result = hb->getResult();
 
-    auto regex = QRegularExpression(
-                QStringLiteral("^Paragraph \\*with /some/\\*/ formatted/ text.\\n$"));
+    auto regex = QRegularExpression(QStringLiteral("^Paragraph \\*with /some/\\*/ formatted/ text.\\n$"));
 
     QVERIFY(regex.match(result).hasMatch());
     delete md;
     delete hb;
     delete doc;
-
 }
 
 void PlainTextMarkupBuilderTest::testEdgeCaseLeft()
@@ -369,14 +343,12 @@ void PlainTextMarkupBuilderTest::testEdgeCaseLeft()
     md->processDocument(doc);
     auto result = hb->getResult();
 
-    auto regex = QRegularExpression(
-                QStringLiteral("^Paragraph \\*with some formatted text.\\*\\n$"));
+    auto regex = QRegularExpression(QStringLiteral("^Paragraph \\*with some formatted text.\\*\\n$"));
 
     QVERIFY(regex.match(result).hasMatch());
     delete md;
     delete hb;
     delete doc;
-
 }
 
 void PlainTextMarkupBuilderTest::testEdgeCaseRight()
@@ -389,37 +361,34 @@ void PlainTextMarkupBuilderTest::testEdgeCaseRight()
     md->processDocument(doc);
     auto result = hb->getResult();
 
-    auto regex = QRegularExpression(
-                QStringLiteral("^\\*Paragraph with some formatted\\* text.\\n$"));
+    auto regex = QRegularExpression(QStringLiteral("^\\*Paragraph with some formatted\\* text.\\n$"));
 
     QVERIFY(regex.match(result).hasMatch());
     delete md;
     delete hb;
     delete doc;
-
 }
 
 void PlainTextMarkupBuilderTest::testImage()
 {
     auto doc = new QTextDocument();
     doc->setHtml(
-                QStringLiteral("Paragraph with an inline <img "
-                               "src=\"http://kde.org/img/kde41.png\" /> image."));
+        QStringLiteral("Paragraph with an inline <img "
+                       "src=\"http://kde.org/img/kde41.png\" /> image."));
 
     auto hb = new KPIMTextEdit::PlainTextMarkupBuilder();
     auto md = new KPIMTextEdit::MarkupDirector(hb);
     md->processDocument(doc);
     auto result = hb->getResult();
 
-    auto regex = QRegularExpression(QStringLiteral(
-                                        "^Paragraph with an inline \\[1\\] image.\\n\\n--------\\n\\[1\\] "
-                                        "http://kde.org/img/kde41.png\\n$"));
+    auto regex =
+        QRegularExpression(QStringLiteral("^Paragraph with an inline \\[1\\] image.\\n\\n--------\\n\\[1\\] "
+                                          "http://kde.org/img/kde41.png\\n$"));
 
     QVERIFY(regex.match(result).hasMatch());
     delete md;
     delete hb;
     delete doc;
-
 }
 
 void PlainTextMarkupBuilderTest::testImageResized()
@@ -431,24 +400,24 @@ void PlainTextMarkupBuilderTest::testImageResized()
     auto doc = new QTextDocument();
 
     // width
-    doc->setHtml(QStringLiteral(
-                     "Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" "
-                     "width=\"10\" /> image."));
+    doc->setHtml(
+        QStringLiteral("Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" "
+                       "width=\"10\" /> image."));
 
     hb = new KPIMTextEdit::PlainTextMarkupBuilder();
     md = new KPIMTextEdit::MarkupDirector(hb);
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegularExpression(QStringLiteral(
-                                   "^Paragraph with an inline \\[1\\] image.\\n\\n--------\\n\\[1\\] "
-                                   "http://kde.org/img/kde41.png\\n$"));
+    regex =
+        QRegularExpression(QStringLiteral("^Paragraph with an inline \\[1\\] image.\\n\\n--------\\n\\[1\\] "
+                                          "http://kde.org/img/kde41.png\\n$"));
     QVERIFY(regex.match(result).hasMatch());
 
     // height
-    doc->setHtml(QStringLiteral(
-                     "Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" "
-                     "height=\"10\" /> image."));
+    doc->setHtml(
+        QStringLiteral("Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" "
+                       "height=\"10\" /> image."));
 
     delete md;
     delete hb;
@@ -458,15 +427,15 @@ void PlainTextMarkupBuilderTest::testImageResized()
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegularExpression(QStringLiteral(
-                                   "^Paragraph with an inline \\[1\\] image.\\n\\n--------\\n\\[1\\] "
-                                   "http://kde.org/img/kde41.png\\n$"));
+    regex =
+        QRegularExpression(QStringLiteral("^Paragraph with an inline \\[1\\] image.\\n\\n--------\\n\\[1\\] "
+                                          "http://kde.org/img/kde41.png\\n$"));
     QVERIFY(regex.match(result).hasMatch());
 
     // height and width
-    doc->setHtml(QStringLiteral(
-                     "Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" "
-                     "height=\"10\" width=\"10\" /> image."));
+    doc->setHtml(
+        QStringLiteral("Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" "
+                       "height=\"10\" width=\"10\" /> image."));
 
     delete md;
     delete hb;
@@ -476,15 +445,14 @@ void PlainTextMarkupBuilderTest::testImageResized()
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegularExpression(QStringLiteral(
-                                   "^Paragraph with an inline \\[1\\] image.\\n\\n--------\\n\\[1\\] "
-                                   "http://kde.org/img/kde41.png\\n$"));
+    regex =
+        QRegularExpression(QStringLiteral("^Paragraph with an inline \\[1\\] image.\\n\\n--------\\n\\[1\\] "
+                                          "http://kde.org/img/kde41.png\\n$"));
 
     QVERIFY(regex.match(result).hasMatch());
     delete md;
     delete hb;
     delete doc;
-
 }
 
 void PlainTextMarkupBuilderTest::testEachFormatTagSingly()
@@ -554,8 +522,7 @@ void PlainTextMarkupBuilderTest::testEachFormatTagSingly()
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegularExpression(
-                QStringLiteral("^Some \\^\\{formatted\\} text.\\n$"));
+    regex = QRegularExpression(QStringLiteral("^Some \\^\\{formatted\\} text.\\n$"));
     QVERIFY(regex.match(result).hasMatch());
 
     // Test Subscript
@@ -568,13 +535,11 @@ void PlainTextMarkupBuilderTest::testEachFormatTagSingly()
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex
-            = QRegularExpression(QStringLiteral("^Some _\\{formatted\\} text.\\n$"));
+    regex = QRegularExpression(QStringLiteral("^Some _\\{formatted\\} text.\\n$"));
     QVERIFY(regex.match(result).hasMatch());
 
     // Test Foreground
-    doc->setHtml(QStringLiteral(
-                     "Some <span style=\"color:#ff0000;\">formatted</span> text."));
+    doc->setHtml(QStringLiteral("Some <span style=\"color:#ff0000;\">formatted</span> text."));
     delete md;
     delete hb;
 
@@ -587,8 +552,7 @@ void PlainTextMarkupBuilderTest::testEachFormatTagSingly()
     QVERIFY(regex.match(result).hasMatch());
 
     // Test Background
-    doc->setHtml(QStringLiteral(
-                     "Some <span style=\"background-color:#ff0000;\">formatted</span> text."));
+    doc->setHtml(QStringLiteral("Some <span style=\"background-color:#ff0000;\">formatted</span> text."));
     delete md;
     delete hb;
 
@@ -601,8 +565,7 @@ void PlainTextMarkupBuilderTest::testEachFormatTagSingly()
     QVERIFY(regex.match(result).hasMatch());
 
     // Test Font Family
-    doc->setHtml(QStringLiteral(
-                     "Some <span style=\"font-family:courier;\">formatted</span> text."));
+    doc->setHtml(QStringLiteral("Some <span style=\"font-family:courier;\">formatted</span> text."));
     delete md;
     delete hb;
 
@@ -615,8 +578,7 @@ void PlainTextMarkupBuilderTest::testEachFormatTagSingly()
     QVERIFY(regex.match(result).hasMatch());
 
     // Test Font Size
-    doc->setHtml(QStringLiteral(
-                     "Some <span style=\"font-size:20pt;\">formatted</span> text."));
+    doc->setHtml(QStringLiteral("Some <span style=\"font-size:20pt;\">formatted</span> text."));
     delete md;
     delete hb;
 
@@ -630,29 +592,26 @@ void PlainTextMarkupBuilderTest::testEachFormatTagSingly()
     delete md;
     delete hb;
     delete doc;
-
 }
 
 void PlainTextMarkupBuilderTest::testHorizontalRule()
 {
     auto doc = new QTextDocument();
     doc->setHtml(
-                QStringLiteral("<p style=\"margin-top:0;margin-bottom:0;\">Foo</p><hr "
-                               "/><p style=\"margin-top:0;margin-bottom:0;\">Bar</p>"));
+        QStringLiteral("<p style=\"margin-top:0;margin-bottom:0;\">Foo</p><hr "
+                       "/><p style=\"margin-top:0;margin-bottom:0;\">Bar</p>"));
 
     auto hb = new KPIMTextEdit::PlainTextMarkupBuilder();
     auto md = new KPIMTextEdit::MarkupDirector(hb);
     md->processDocument(doc);
     auto result = hb->getResult();
 
-    auto regex = QRegularExpression(
-                QStringLiteral("^Foo\\n--------------------\\nBar\\n$"));
+    auto regex = QRegularExpression(QStringLiteral("^Foo\\n--------------------\\nBar\\n$"));
 
     QVERIFY(regex.match(result).hasMatch());
     delete md;
     delete hb;
     delete doc;
-
 }
 
 void PlainTextMarkupBuilderTest::testNewlines()
@@ -671,7 +630,6 @@ void PlainTextMarkupBuilderTest::testNewlines()
     delete md;
     delete hb;
     delete doc;
-
 }
 
 void PlainTextMarkupBuilderTest::testEmptyParagraphs()
@@ -690,7 +648,6 @@ void PlainTextMarkupBuilderTest::testEmptyParagraphs()
     delete md;
     delete hb;
     delete doc;
-
 }
 
 void PlainTextMarkupBuilderTest::testNewlinesThroughQTextCursor()
@@ -715,12 +672,10 @@ void PlainTextMarkupBuilderTest::testNewlinesThroughQTextCursor()
     delete md;
     delete hb;
     delete doc;
-
 }
 
 void PlainTextMarkupBuilderTest::testBrInsideParagraph()
 {
-
     auto doc = new QTextDocument();
     doc->setHtml(QStringLiteral("<p>Foo<br /><br /><br />Bar</p>"));
 
@@ -737,7 +692,6 @@ void PlainTextMarkupBuilderTest::testBrInsideParagraph()
     delete md;
     delete hb;
     delete doc;
-
 }
 
 void PlainTextMarkupBuilderTest::testLongDocument()
@@ -752,23 +706,20 @@ void PlainTextMarkupBuilderTest::testLongDocument()
     auto md = new KPIMTextEdit::MarkupDirector(hb);
     md->processDocument(&doc);
     auto result = hb->getResult();
-    QVERIFY2(
-                result.startsWith(QLatin1String("Hello,\nThis is some text\nIt shows how "
-                                                "grantlee is used from kmail\n")),
-                qPrintable(result));
-    QVERIFY2(result.endsWith(QLatin1String("This is the end of the signature\n")),
+    QVERIFY2(result.startsWith(QLatin1String("Hello,\nThis is some text\nIt shows how "
+                                             "grantlee is used from kmail\n")),
              qPrintable(result));
+    QVERIFY2(result.endsWith(QLatin1String("This is the end of the signature\n")), qPrintable(result));
     // qDebug() << result;
     delete md;
     delete hb;
 }
 
-
 void PlainTextMarkupBuilderTest::testBrInsideAnchor()
 {
-
     auto doc = new QTextDocument();
-    doc->setHtml(QStringLiteral("<html><body><p >url: <a href=\"https://www.kde.org\"><span>foo</span></a><br />line1<br />line2</p><p>-- </p><p>bla</p><br /></p></body></html>"));
+    doc->setHtml(QStringLiteral(
+        "<html><body><p >url: <a href=\"https://www.kde.org\"><span>foo</span></a><br />line1<br />line2</p><p>-- </p><p>bla</p><br /></p></body></html>"));
 
     auto hb = new KPIMTextEdit::PlainTextMarkupBuilder();
     auto md = new KPIMTextEdit::MarkupDirector(hb);
