@@ -1,16 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TEXTGOTOLINEWIDGET_H
-#define TEXTGOTOLINEWIDGET_H
+#pragma once
 
 #include "kpimtextedit_export.h"
 #include <QWidget>
 
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class TextGoToLineWidgetPrivate;
 /**
  * @brief The TextGoToLineWidget class
@@ -33,6 +33,7 @@ Q_SIGNALS:
 protected:
     bool event(QEvent *e) override;
     void showEvent(QShowEvent *e) override;
+    bool eventFilter(QObject *obj, QEvent *event) override;
 
 public Q_SLOTS:
     void slotBlockCountChanged(int numberBlockCount);
@@ -45,4 +46,3 @@ private:
     TextGoToLineWidgetPrivate *const d;
 };
 }
-#endif // TEXTGOTOLINEWIDGET_H
